@@ -154,6 +154,12 @@ public:
 
     bool dbgGetAlwaysFailDialing();
 
+    // Periodic update settings get and set
+    bool setRefreshSettings (bool enable, quint32 contactsPeriod,
+                             quint32 inboxPeriod);
+    bool getRefreshSettings (bool &enable, quint32 &contactsPeriod,
+                             quint32 &inboxPeriod);
+
 private:
     bool putContactInfo (const ContactInfo &info);
     bool deleteContactInfo (const QString &strId);
